@@ -1,7 +1,7 @@
 # crsLL = CRS("+epsg:4326")
 crsLL = CRS("+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0") 
 
-.extentLL = function(x, crs=NULL) {
+.extentLL = function(x, crs=NA) {
 
 	eps = 1e-5
 	if(is.numeric(x))
@@ -25,6 +25,10 @@ crsLL = CRS("+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0")
 	
 	x = raster(extent(x), nrows=100,ncols=100, crs=crsUse)
 
-	extent(projectExtent(x, crsLL))
-	
+	if(requireNamespace('rgdal', quietly=TRUE)) {
+		result = extent(projectExtent(x, crsLL))
+	} else {
+		result = extent(x)
+	}	
+	result
 }
\ No newline at end of file
